==> rendition-8.15.1.tgz: package/dist_esm5/components/DataTypes/oneOf.js <==
import * as tslib_1 from "tslib";
import assign from 'lodash/assign';
import map from 'lodash/map';
import * as React from 'react';
import * as utils from '../../utils';
import Select from '../Select';
var getCaption = function (value, schema) {
    var item = schema.oneOf.find(function (item) { return item.const === value; });
    return item ? item.title : '';
};
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    is_not: {
        getLabel: function (_s) { return 'is not'; },
    },
};
export var decodeFilter = function (filter) {
    var operator = filter.title;
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var value;
    var field = keys[0];
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else if (operator === 'is_not') {
        value = filter.properties[field].not.const;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: (title || field) + " " + operators[operator].getLabel(schema) + " " + getCaption(value, schema),
        type: 'object',
    };
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    const: value,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'is_not') {
        return assign(base, {
            properties: (_b = {},
                _b[field] = {
                    not: {
                        const: value,
                    },
                },
                _b),
        });
    }
    return base;
};
export var Edit = function (_a) {
    var schema = _a.schema, value = _a.value, onUpdate = _a.onUpdate, props = tslib_1.__rest(_a, ["schema", "value", "onUpdate"]);
    return (React.createElement(Select, tslib_1.__assign({}, props, { value: value, onChange: function (e) {
            return onUpdate(e.currentTarget.value);
        } }), map(schema.oneOf, function (item) { return (React.createElement("option", { key: '' + item.const, value: '' + item.const }, item.title)); })));
};

==> rendition-9.0.0.tgz: package/dist_esm5/components/DataTypes/oneOf.js <==
import * as tslib_1 from "tslib";
import assign from 'lodash/assign';
import * as React from 'react';
import * as utils from '../../utils';
import Select from '../Select';
var getCaption = function (value, schema) {
    var item = schema.oneOf.find(function (item) { return item.const === value; });
    return item ? item.title : '';
};
export var operators = {
    is: {
        getLabel: function (_s) { return 'is'; },
    },
    is_not: {
        getLabel: function (_s) { return 'is not'; },
    },
};
export var decodeFilter = function (filter) {
    var operator = filter.title;
    if (!filter.properties) {
        return null;
    }
    var keys = Object.keys(filter.properties);
    if (!keys.length) {
        return null;
    }
    var value;
    var field = keys[0];
    if (operator === 'is') {
        value = filter.properties[field].const;
    }
    else if (operator === 'is_not') {
        value = filter.properties[field].not.const;
    }
    else {
        return null;
    }
    return {
        field: field,
        operator: operator,
        value: value,
    };
};
export var createFilter = function (field, operator, value, schema) {
    var _a, _b;
    var title = schema.title;
    var base = {
        $id: utils.randomString(),
        title: operator,
        description: (title || field) + " " + operators[operator].getLabel(schema) + " " + getCaption(value, schema),
        type: 'object',
    };
    if (operator === 'is') {
        return assign(base, {
            properties: (_a = {},
                _a[field] = {
                    const: value,
                },
                _a),
            required: [field],
        });
    }
    if (operator === 'is_not') {
        return assign(base, {
            properties: (_b = {},
                _b[field] = {
                    not: {
                        const: value,
                    },
                },
                _b),
        });
    }
    return base;
};
export var Edit = function (_a) {
    var schema = _a.schema, value = _a.value, onUpdate = _a.onUpdate, props = tslib_1.__rest(_a, ["schema", "value", "onUpdate"]);
    return (React.createElement(Select, tslib_1.__assign({}, props, { options: schema.oneOf || [], valueKey: "const", labelKey: "title", value: (schema.oneOf || []).find(function (x) { return x.const === value; }), onChange: function (_a) {
            var option = _a.option;
            return onUpdate(option.const.toString());
        } })));
};
